@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-open-location-dialog.c 5786 2007-08-12 12:36:30Z vgeddes $
+ * $Id: gedit-open-location-dialog.c 6379 2008-08-10 16:40:21Z pborelli $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,7 +33,8 @@
 #endif
 
 #include <glib/gi18n.h>
-#include <libgnomevfs/gnome-vfs-utils.h>
+#include <gio/gio.h>
+#include <gtk/gtk.h>
 
 #include "gedit-open-location-dialog.h"
 #include "gedit-history-entry.h"
@@ -81,7 +82,7 @@ response_handler (GeditOpenLocationDialog *dlg,
                   gint                     response_id,
                   gpointer                 data)
 {
-	gchar *uri;
+	const gchar *text;
 
 	switch (response_id)
 	{
@@ -94,18 +95,13 @@ response_handler (GeditOpenLocationDialog *dlg,
 			break;
 
 		case GTK_RESPONSE_OK:
-			uri = gedit_open_location_dialog_get_uri (dlg);
-			if (uri != NULL)
+			text = gtk_entry_get_text
+					(GTK_ENTRY (dlg->priv->uri_text_entry));
+			if (*text != '\0')
 			{
-				const gchar *text;
-
-				text = gtk_entry_get_text
-						(GTK_ENTRY (dlg->priv->uri_text_entry));
 				gedit_history_entry_prepend_text
 						 (GEDIT_HISTORY_ENTRY (dlg->priv->uri_entry),
 						  text);
-
-				g_free (uri);
 			}
 			break;
 	}
@@ -121,6 +117,10 @@ gedit_open_location_dialog_init (GeditOpenLocationDialog *dlg)
 	GtkWidget *encoding_hbox;
 	GtkWidget *error_widget;
 	gboolean   ret;
+	gchar     *root_objects[] = {
+		"open_uri_dialog_content",
+		NULL
+	};
 
 	dlg->priv = GEDIT_OPEN_LOCATION_DIALOG_GET_PRIVATE (dlg);
 
@@ -154,15 +154,15 @@ gedit_open_location_dialog_init (GeditOpenLocationDialog *dlg)
 			  G_CALLBACK (response_handler),
 			  NULL);
 
-	ret = gedit_utils_get_glade_widgets (GEDIT_GLADEDIR "gedit-open-location-dialog.glade",
-					     "open_uri_dialog_content",
-					     &error_widget,
-					     "open_uri_dialog_content", &content,
-					     "main_vbox", &vbox,
-					     "location_label", &location_label,
-					     "encoding_label", &encoding_label,
-					     "encoding_hbox", &encoding_hbox,
-					     NULL);
+	ret = gedit_utils_get_ui_objects (GEDIT_UIDIR "gedit-open-location-dialog.ui",
+					  root_objects,
+					  &error_widget,
+					  "open_uri_dialog_content", &content,
+					  "main_vbox", &vbox,
+					  "location_label", &location_label,
+					  "encoding_label", &encoding_label,
+					  "encoding_hbox", &encoding_hbox,
+					   NULL);
 
 	if (!ret)
 	{
@@ -208,6 +208,7 @@ gedit_open_location_dialog_init (GeditOpenLocationDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
 			    content, FALSE, FALSE, 0);
+	g_object_unref (content);
 	gtk_container_set_border_width (GTK_CONTAINER (content), 5);			    
 }
 
@@ -225,14 +226,11 @@ gedit_open_location_dialog_new (GtkWindow *parent)
 	return dlg;
 }
 
-/* Always return a valid gnome vfs uri or NULL */
-gchar *
-gedit_open_location_dialog_get_uri (GeditOpenLocationDialog *dlg)
+GFile *
+gedit_open_location_dialog_get_location (GeditOpenLocationDialog *dlg)
 {
 	const gchar *str;
-	gchar *uri;
-	gchar *canonical_uri;
-	GnomeVFSURI *vfs_uri;
+	GFile *location;
 
 	g_return_val_if_fail (GEDIT_IS_OPEN_LOCATION_DIALOG (dlg), NULL);
 
@@ -242,25 +240,9 @@ gedit_open_location_dialog_get_uri (GeditOpenLocationDialog *dlg)
 	if (str[0] == '\0')
 		return NULL;
 
-	uri = gnome_vfs_make_uri_from_input_with_dirs (str,
-						       GNOME_VFS_MAKE_URI_DIR_CURRENT);
-	g_return_val_if_fail (uri != NULL, NULL);
+	location = g_file_new_for_commandline_arg (str);
 
-	canonical_uri = gnome_vfs_make_uri_canonical (uri);
-	g_free (uri);
-
-	g_return_val_if_fail (canonical_uri != NULL, NULL);
-
-	vfs_uri = gnome_vfs_uri_new (canonical_uri);
-	if (vfs_uri == NULL)
-	{
-		g_free (canonical_uri);
-		return NULL;
-	}
-
-	gnome_vfs_uri_unref (vfs_uri);
-
-	return canonical_uri;
+	return location;
 }
 
 const GeditEncoding *
