@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-io-error-message-area.h,v 1.3 2006/12/17 15:11:00 pborelli Exp $
+ * $Id: gedit-io-error-message-area.h 5428 2007-01-08 22:02:42Z pborelli $
  */
 
 #ifndef __GEDIT_IO_ERROR_MESSAGE_AREA_H__
@@ -63,6 +63,9 @@ GtkWidget	*gedit_no_backup_saving_error_message_area_new		 (const gchar
 GtkWidget	*gedit_unrecoverable_saving_error_message_area_new	 (const gchar         *uri,
 									  const GError        *error);
 
+GtkWidget	*gedit_externally_modified_message_area_new		 (const gchar         *uri,
+									  gboolean             document_modified);
+
 G_END_DECLS
 
 #endif  /* __GEDIT_IO_ERROR_MESSAGE_AREA_H__  */
