@@ -35,16 +35,18 @@
 #include "gedit-file-browser-error.h"
 #include "gedit-file-browser-utils.h"
 
-#define GEDIT_FILE_BROWSER_STORE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GEDIT_TYPE_FILE_BROWSER_STORE, GeditFileBrowserStorePrivate))
+#define GEDIT_FILE_BROWSER_STORE_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), \
+						     GEDIT_TYPE_FILE_BROWSER_STORE, \
+						     GeditFileBrowserStorePrivate))
 
-#define NODE_IS_DIR(node)				(FILE_IS_DIR((node)->flags))
-#define NODE_IS_HIDDEN(node)			(FILE_IS_HIDDEN((node)->flags))
-#define NODE_IS_TEXT(node)				(FILE_IS_TEXT((node)->flags))
-#define NODE_LOADED(node)				(FILE_LOADED((node)->flags))
-#define NODE_IS_FILTERED(node)			(FILE_IS_FILTERED((node)->flags))
-#define NODE_IS_DUMMY(node)				(FILE_IS_DUMMY((node)->flags))
+#define NODE_IS_DIR(node)		(FILE_IS_DIR((node)->flags))
+#define NODE_IS_HIDDEN(node)		(FILE_IS_HIDDEN((node)->flags))
+#define NODE_IS_TEXT(node)		(FILE_IS_TEXT((node)->flags))
+#define NODE_LOADED(node)		(FILE_LOADED((node)->flags))
+#define NODE_IS_FILTERED(node)		(FILE_IS_FILTERED((node)->flags))
+#define NODE_IS_DUMMY(node)		(FILE_IS_DUMMY((node)->flags))
 
-#define FILE_BROWSER_NODE_DIR(node)		((FileBrowserNodeDir *)(node))
+#define FILE_BROWSER_NODE_DIR(node)	((FileBrowserNodeDir *)(node))
 
 #define DIRECTORY_LOAD_ITEMS_PER_CALLBACK 100
 #define STANDARD_ATTRIBUTE_TYPES G_FILE_ATTRIBUTE_STANDARD_TYPE "," \
@@ -76,6 +78,7 @@ struct _AsyncNode
 {
 	FileBrowserNodeDir *dir;
 	GCancellable *cancellable;
+	GSList *original_children;
 };
 
 struct _FileBrowserNode 
@@ -226,10 +229,10 @@ gedit_file_browser_store_finalize (GObject * object)
 	GeditFileBrowserStore *obj = GEDIT_FILE_BROWSER_STORE (object);
 	GSList *item;
 
-	// Free all the nodes
+	/* Free all the nodes */
 	file_browser_node_free (obj, obj->priv->root);
 
-	// Cancel any asynchronous operations
+	/* Cancel any asynchronous operations */
 	for (item = obj->priv->async_handles; item; item = item->next)
 	{
 		AsyncData *data = (AsyncData *) (item->data);
@@ -239,8 +242,7 @@ gedit_file_browser_store_finalize (GObject * object)
 	}
 
 	g_slist_free (obj->priv->async_handles);
-	G_OBJECT_CLASS (gedit_file_browser_store_parent_class)->
-	    finalize (object);
+	G_OBJECT_CLASS (gedit_file_browser_store_parent_class)->finalize (object);
 }
 
 static void
@@ -249,9 +251,9 @@ set_gvalue_from_node (GValue          *value,
 {
 	gchar * uri;
 
-	if (node == NULL || !node->file)
+	if (node == NULL || !node->file) {
 		g_value_set_string (value, NULL);
-	else {
+	} else {
 		uri = g_file_get_uri (node->file);
 		g_value_take_string (value, uri);
 	}
@@ -533,9 +535,7 @@ gedit_file_browser_store_get_iter (GtkTreeModel * tree_model,
 {
 	gint * indices, depth, i;
 	FileBrowserNode * node;
-	FileBrowserNode * child;
 	GeditFileBrowserStore * model;
-	GSList * item;
 	gint num;
 
 	g_assert (GEDIT_IS_FILE_BROWSER_STORE (tree_model));
@@ -547,6 +547,8 @@ gedit_file_browser_store_get_iter (GtkTreeModel * tree_model,
 	node = model->priv->virtual_root;
 
 	for (i = 0; i < depth; ++i) {
+		GSList * item;
+
 		if (node == NULL)
 			return FALSE;
 
@@ -556,6 +558,8 @@ gedit_file_browser_store_get_iter (GtkTreeModel * tree_model,
 			return FALSE;
 
 		for (item = FILE_BROWSER_NODE_DIR (node)->children; item; item = item->next) {
+			FileBrowserNode * child;
+
 			child = (FileBrowserNode *) (item->data);
 
 			if (model_node_inserted (model, child)) {
@@ -585,12 +589,14 @@ static GtkTreePath *
 gedit_file_browser_store_get_path_real (GeditFileBrowserStore * model,
 					FileBrowserNode * node)
 {
-	GtkTreePath *path = gtk_tree_path_new ();
-	FileBrowserNode *check;
-	GSList *item;
+	GtkTreePath *path;
 	gint num = 0;
-	
+
+	path = gtk_tree_path_new ();
+
 	while (node != model->priv->virtual_root) {
+		GSList *item;
+
 		if (node->parent == NULL) {
 			gtk_tree_path_free (path);
 			return NULL;
@@ -599,6 +605,8 @@ gedit_file_browser_store_get_path_real (GeditFileBrowserStore * model,
 		num = 0;
 
 		for (item = FILE_BROWSER_NODE_DIR (node->parent)->children; item; item = item->next) {
+			FileBrowserNode *check;
+
 			check = (FileBrowserNode *) (item->data);
 
 			if (model_node_visibility (model, check)) {
@@ -628,16 +636,12 @@ static GtkTreePath *
 gedit_file_browser_store_get_path (GtkTreeModel * tree_model,
 				   GtkTreeIter * iter)
 {
-	FileBrowserNode *node;
-
 	g_return_val_if_fail (GEDIT_IS_FILE_BROWSER_STORE (tree_model), NULL);
 	g_return_val_if_fail (iter != NULL, NULL);
 	g_return_val_if_fail (iter->user_data != NULL, NULL);
 
-	node = (FileBrowserNode *) (iter->user_data);
-
 	return gedit_file_browser_store_get_path_real (GEDIT_FILE_BROWSER_STORE (tree_model), 
-						       node);
+						       (FileBrowserNode *) (iter->user_data));
 }
 
 static void
@@ -1372,7 +1376,8 @@ file_browser_node_free (GeditFileBrowserStore * model,
  **/
 static void
 model_remove_node_children (GeditFileBrowserStore * model,
-			    FileBrowserNode * node, GtkTreePath * path,
+			    FileBrowserNode * node,
+			    GtkTreePath * path,
 			    gboolean free_nodes)
 {
 	FileBrowserNodeDir *dir;
@@ -1407,9 +1412,10 @@ model_remove_node_children (GeditFileBrowserStore * model,
 
 	list = g_slist_copy (dir->children);
 
-	for (item = list; item; item = item->next)
+	for (item = list; item; item = item->next) {
 		model_remove_node (model, (FileBrowserNode *) (item->data),
 				   path_child, free_nodes);
+	}
 
 	g_slist_free (list);
 	gtk_tree_path_free (path_child);
@@ -1428,15 +1434,14 @@ model_remove_node_children (GeditFileBrowserStore * model,
  * a node.
  **/
 static void
-model_remove_node (GeditFileBrowserStore * model, FileBrowserNode * node,
-		   GtkTreePath * path, gboolean free_nodes)
+model_remove_node (GeditFileBrowserStore * model,
+		   FileBrowserNode * node,
+		   GtkTreePath * path,
+		   gboolean free_nodes)
 {
 	gboolean free_path = FALSE;
 	FileBrowserNode *parent;
 
-	if (node == NULL)
-		return;
-
 	if (path == NULL) {
 		path =
 		    gedit_file_browser_store_get_path_real (model, node);
@@ -1518,8 +1523,6 @@ model_clear (GeditFileBrowserStore * model, gboolean free_nodes)
 	}
 }
 
-/* ====================================================================== */
-
 static void
 file_browser_node_unload (GeditFileBrowserStore * model,
 			  FileBrowserNode * node, gboolean remove_children)
@@ -1571,10 +1574,15 @@ model_recomposite_icon_real (GeditFileBrowserStore * tree_model,
 
 	theme = gtk_icon_theme_get_default ();
 	
-	if (info)
-		icon = gedit_file_browser_utils_pixbuf_from_icon (g_file_info_get_icon (info), GTK_ICON_SIZE_MENU);
-	else
+	if (info) {
+		GIcon *gicon = g_file_info_get_icon (info);
+		if (gicon != NULL)
+			icon = gedit_file_browser_utils_pixbuf_from_icon (gicon, GTK_ICON_SIZE_MENU);
+		else
+			icon = NULL;
+	} else {
 		icon = gedit_file_browser_utils_pixbuf_from_file (node->file, GTK_ICON_SIZE_MENU);
+	}
 
 	if (node->icon)
 		g_object_unref (node->icon);
@@ -1655,14 +1663,14 @@ model_add_dummy_node (GeditFileBrowserStore * model,
 static void
 model_check_dummy (GeditFileBrowserStore * model, FileBrowserNode * node)
 {
-	FileBrowserNode *dummy;
-	FileBrowserNodeDir *dir;
-	GtkTreeIter iter;
-	GtkTreePath *path;
-	guint flags;
-
 	// Hide the dummy child if needed
 	if (NODE_IS_DIR (node)) {
+		FileBrowserNode *dummy;
+		GtkTreeIter iter;
+		GtkTreePath *path;
+		guint flags;
+		FileBrowserNodeDir *dir;
+
 		dir = FILE_BROWSER_NODE_DIR (node);
 
 		if (dir->children == NULL) {
@@ -1674,8 +1682,7 @@ model_check_dummy (GeditFileBrowserStore * model, FileBrowserNode * node)
 
 		if (!NODE_IS_DUMMY (dummy)) {
 			dummy = model_create_dummy_node (model, node);
-			dir->children =
-			    g_slist_prepend (dir->children, dummy);
+			dir->children = g_slist_prepend (dir->children, dummy);
 		}
 
 		if (!model_node_visibility (model, node)) {
@@ -1683,7 +1690,9 @@ model_check_dummy (GeditFileBrowserStore * model, FileBrowserNode * node)
 			    GEDIT_FILE_BROWSER_STORE_FLAG_IS_HIDDEN;
 			return;
 		}
-		// Temporarily set the node to invisible to check for real childs
+
+		/* Temporarily set the node to invisible to check
+		 * for real children */
 		flags = dummy->flags;
 		dummy->flags |= GEDIT_FILE_BROWSER_STORE_FLAG_IS_HIDDEN;
 
@@ -1723,7 +1732,8 @@ model_check_dummy (GeditFileBrowserStore * model, FileBrowserNode * node)
 }
 
 static void
-insert_node_sorted (GeditFileBrowserStore * model, FileBrowserNode * child,
+insert_node_sorted (GeditFileBrowserStore * model,
+		    FileBrowserNode * child,
 		    FileBrowserNode * parent)
 {
 	FileBrowserNodeDir *dir;
@@ -1744,19 +1754,18 @@ static void
 model_add_node (GeditFileBrowserStore * model, FileBrowserNode * child,
 		FileBrowserNode * parent)
 {
-	GtkTreeIter iter;
-	GtkTreePath *path;
-
-	// Add child to parents children
+	/* Add child to parents children */
 	insert_node_sorted (model, child, parent);
 
 	if (model_node_visibility (model, parent) &&
 	    model_node_visibility (model, child)) {
-		iter.user_data = child;
-		path =
-		    gedit_file_browser_store_get_path_real (model, child);
+		GtkTreeIter iter;
+		GtkTreePath *path;
 
-		// Emit row inserted
+		iter.user_data = child;
+		path = gedit_file_browser_store_get_path_real (model, child);
+
+		/* Emit row inserted */
 		row_inserted (model, &path, &iter);
 		gtk_tree_path_free (path);
 	}
@@ -1765,6 +1774,92 @@ model_add_node (GeditFileBrowserStore * model, FileBrowserNode * child,
 	model_check_dummy (model, child);
 }
 
+static void
+model_add_nodes_batch (GeditFileBrowserStore * model,
+		       GSList * children,
+		       FileBrowserNode * parent)
+{
+	GSList *sorted_children;
+	GSList *child;
+	GSList *prev;
+	GSList *l;
+	FileBrowserNodeDir *dir;
+
+	dir = FILE_BROWSER_NODE_DIR (parent);
+
+	sorted_children = g_slist_sort (children, (GCompareFunc) model->priv->sort_func);
+
+	child = sorted_children;
+	l = dir->children;
+	prev = NULL;
+
+	model_check_dummy (model, parent);
+
+	while (child) {
+		FileBrowserNode *node = child->data;
+		GtkTreeIter iter;
+		GtkTreePath *path;
+
+		/* reached the end of the first list, just append the second */
+		if (l == NULL) {
+
+			dir->children = g_slist_concat (dir->children, child);
+
+			for (l = child; l; l = l->next) {
+				if (model_node_visibility (model, parent) &&
+				    model_node_visibility (model, l->data)) {
+					iter.user_data = l->data;
+					path = gedit_file_browser_store_get_path_real (model, l->data);
+
+					// Emit row inserted
+					row_inserted (model, &path, &iter);
+					gtk_tree_path_free (path);
+				}
+
+				model_check_dummy (model, l->data);
+			}
+
+			break;
+		}
+
+		if (model->priv->sort_func (l->data, node) > 0) {
+			GSList *next_child;
+
+			if (prev == NULL) {
+				/* prepend to the list */
+				dir->children = g_slist_prepend (dir->children, child);
+			} else {
+				prev->next = child;
+			}
+
+			next_child = child->next;
+			prev = child;
+			child->next = l;
+			child = next_child;
+
+			if (model_node_visibility (model, parent) &&
+			    model_node_visibility (model, node)) {
+				iter.user_data = node;
+				path = gedit_file_browser_store_get_path_real (model, node);
+
+				// Emit row inserted
+				row_inserted (model, &path, &iter);
+				gtk_tree_path_free (path);
+			}
+
+			model_check_dummy (model, node);
+
+			/* try again at the same l position with the
+			 * next child */
+		} else {
+
+			/* Move to the next item in the list */
+			prev = l;
+			l = l->next;
+		}
+	}
+}
+
 static gchar const *
 backup_content_type (GFileInfo * info)
 {
@@ -1854,17 +1949,13 @@ file_browser_node_set_from_info (GeditFileBrowserStore * model,
 }
 
 static FileBrowserNode *
-model_file_exists (GeditFileBrowserStore * model, FileBrowserNode * parent,
-		  GFile * file)
+node_list_contains_file (GSList *children, GFile * file)
 {
 	GSList *item;
-	FileBrowserNode *node;
 
-	if (!NODE_IS_DIR (parent))
-		return NULL;
+	for (item = children; item; item = item->next) {
+		FileBrowserNode *node;
 
-	for (item = FILE_BROWSER_NODE_DIR (parent)->children; item;
-	     item = item->next) {
 		node = (FileBrowserNode *) (item->data);
 
 		if (node->file != NULL
@@ -1885,9 +1976,8 @@ model_add_node_from_file (GeditFileBrowserStore * model,
 	gboolean free_info = FALSE;
 	GError * error = NULL;
 
-	// Check if it already exists
-	if ((node = model_file_exists (model, parent, file)) == NULL) {	
-		if (!info) {
+	if ((node = node_list_contains_file (FILE_BROWSER_NODE_DIR (parent)->children, file)) == NULL) {
+		if (info == NULL) {
 			info = g_file_query_info (file,
 						  STANDARD_ATTRIBUTE_TYPES,
 						  G_FILE_QUERY_INFO_NONE,
@@ -1895,11 +1985,11 @@ model_add_node_from_file (GeditFileBrowserStore * model,
 						  &error);
 			free_info = TRUE;
 		}
-		
+	
 		if (!info) {
 			g_warning ("Error querying file info: %s", error->message);
 			g_error_free (error);
-			
+		
 			/* FIXME: What to do now then... */
 			node = file_browser_node_new (file, parent);
 		} else if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY) {
@@ -1910,7 +2000,7 @@ model_add_node_from_file (GeditFileBrowserStore * model,
 
 		file_browser_node_set_from_info (model, node, info, FALSE);
 		model_add_node (model, node, parent);
-		
+	
 		if (info && free_info)
 			g_object_unref (info);
 	}
@@ -1918,6 +2008,67 @@ model_add_node_from_file (GeditFileBrowserStore * model,
 	return node;
 }
 
+/* We pass in a copy of the list of parent->children so that we do
+ * not have to check if a file already exists among the ones we just
+ * added */
+static void
+model_add_nodes_from_files (GeditFileBrowserStore * model,
+			    FileBrowserNode * parent,
+			    GSList * original_children,
+			    GList * files)
+{
+	GList *item;
+	GSList *nodes = NULL;
+
+	for (item = files; item; item = item->next) {
+		GFileInfo *info = G_FILE_INFO (item->data);
+		GFileType type;
+		gchar const * name;
+		GFile * file;
+		FileBrowserNode *node;
+
+		type = g_file_info_get_file_type (info);
+
+		/* Skip all non regular, non directory files */
+		if (type != G_FILE_TYPE_REGULAR &&
+		    type != G_FILE_TYPE_DIRECTORY &&
+		    type != G_FILE_TYPE_SYMBOLIC_LINK) {
+			g_object_unref (info);
+			continue;
+		}		
+
+		name = g_file_info_get_name (info);
+
+		/* Skip '.' and '..' directories */
+		if (type == G_FILE_TYPE_DIRECTORY &&
+		    (strcmp (name, ".") == 0 ||
+		     strcmp (name, "..") == 0)) {
+			continue;
+		}
+
+		file = g_file_get_child (parent->file, name);
+
+		if ((node = node_list_contains_file (original_children, file)) == NULL) {
+
+			if (g_file_info_get_file_type (info) == G_FILE_TYPE_DIRECTORY) {
+				node = file_browser_node_dir_new (model, file, parent);
+			} else {
+				node = file_browser_node_new (file, parent);
+			}
+
+			file_browser_node_set_from_info (model, node, info, FALSE);
+
+			nodes = g_slist_prepend (nodes, node);
+		}
+
+		g_object_unref (file);
+		g_object_unref (info);
+	}
+
+	if (nodes)
+		model_add_nodes_batch (model, nodes, parent);
+}
+
 static FileBrowserNode *
 model_add_node_from_dir (GeditFileBrowserStore * model,
 			 FileBrowserNode * parent,
@@ -1926,7 +2077,7 @@ model_add_node_from_dir (GeditFileBrowserStore * model,
 	FileBrowserNode *node;
 
 	/* Check if it already exists */
-	if ((node = model_file_exists (model, parent, file)) == NULL) {	
+	if ((node = node_list_contains_file (FILE_BROWSER_NODE_DIR (parent)->children, file)) == NULL) {	
 		node = file_browser_node_dir_new (model, file, parent);
 		file_browser_node_set_from_info (model, node, NULL, FALSE);
 
@@ -1956,7 +2107,6 @@ parse_dot_hidden_file (FileBrowserNode *directory)
 	int i;
 	FileBrowserNodeDir * dir = FILE_BROWSER_NODE_DIR (directory);
 
-
 	/* FIXME: We only support .hidden on file: uri's for the moment.
 	 * Need to figure out if we should do this async or sync to extend
 	 * it to all types of uris.
@@ -2028,10 +2178,9 @@ on_directory_monitor_event (GFileMonitor * monitor,
 
 	switch (event_type) {
 	case G_FILE_MONITOR_EVENT_DELETED:
-		node = model_file_exists (dir->model, parent, file);
+		node = node_list_contains_file (dir->children, file);
 
 		if (node != NULL) {
-			// Remove the node
 			model_remove_node (dir->model, node, NULL, TRUE);
 		}
 		break;
@@ -2050,6 +2199,7 @@ static void
 async_node_free (AsyncNode *async)
 {
 	g_object_unref (async->cancellable);
+	g_slist_free (async->original_children);
 	g_free (async);
 }
 
@@ -2059,12 +2209,7 @@ model_iterate_next_files_cb (GFileEnumerator * enumerator,
 			     AsyncNode * async)
 {
 	GList * files;
-	GList * item;
 	GError * error = NULL;
-	GFileInfo * info;
-	GFileType type;
-	gchar const * name;
-	GFile * file;
 	FileBrowserNodeDir * dir = async->dir;
 	FileBrowserNode * parent = (FileBrowserNode *)dir;
 	
@@ -2113,30 +2258,7 @@ model_iterate_next_files_cb (GFileEnumerator * enumerator,
 		g_file_enumerator_close (enumerator, NULL, NULL);
 		async_node_free (async);
 	} else {
-		for (item = files; item; item = item->next) {
-			info = G_FILE_INFO (item->data);
-			type = g_file_info_get_file_type (info);
-			
-			/* Skip all non regular, non directory files */
-			if (type != G_FILE_TYPE_REGULAR &&
-			    type != G_FILE_TYPE_DIRECTORY &&
-			    type != G_FILE_TYPE_SYMBOLIC_LINK)
-				continue;
-
-			name = g_file_info_get_name (info);
-
-			/* Skip '.' and '..' directories */
-			if (type == G_FILE_TYPE_DIRECTORY &&
-			    (strcmp (name, ".") == 0 ||
-			     strcmp (name, "..") == 0))
-				continue;
-
-			file = g_file_get_child (parent->file, name);
-			model_add_node_from_file (dir->model, parent, file, info);
-
-			g_object_unref (file);
-			g_object_unref (info);
-		}
+		model_add_nodes_from_files (dir->model, parent, async->original_children, files);
 		
 		g_list_free (files);
 		next_files_async (enumerator, async);
@@ -2216,6 +2338,7 @@ model_load_directory (GeditFileBrowserStore * model,
 	AsyncNode *async = g_new (AsyncNode, 1);
 	async->dir = dir;
 	async->cancellable = g_object_ref (dir->cancellable);
+	async->original_children = g_slist_copy (dir->children);
 
 	/* Start loading async */
 	g_file_enumerate_children_async (node->file,
@@ -2248,7 +2371,7 @@ get_parent_files (GeditFileBrowserStore * model, GFile * file)
 
 static void
 model_fill (GeditFileBrowserStore * model, FileBrowserNode * node,
-	    GtkTreePath * path)
+	    GtkTreePath ** path)
 {
 	gboolean free_path = FALSE;
 	GtkTreeIter iter = {0,};
@@ -2257,19 +2380,19 @@ model_fill (GeditFileBrowserStore * model, FileBrowserNode * node,
 
 	if (node == NULL) {
 		node = model->priv->virtual_root;
-		path = gtk_tree_path_new ();
+		*path = gtk_tree_path_new ();
 		free_path = TRUE;
 	}
 
-	if (path == NULL) {
-		path =
+	if (*path == NULL) {
+		*path =
 		    gedit_file_browser_store_get_path_real (model, node);
 		free_path = TRUE;
 	}
 
 	if (!model_node_visibility (model, node)) {
 		if (free_path)
-			gtk_tree_path_free (path);
+			gtk_tree_path_free (*path);
 
 		return;
 	}
@@ -2278,12 +2401,12 @@ model_fill (GeditFileBrowserStore * model, FileBrowserNode * node,
 		/* Insert node */
 		iter.user_data = node;
 		
-		row_inserted(model, &path, &iter);
+		row_inserted(model, path, &iter);
 	}
 
 	if (NODE_IS_DIR (node)) {
 		/* Go to the first child */
-		gtk_tree_path_down (path);
+		gtk_tree_path_down (*path);
 
 		for (item = FILE_BROWSER_NODE_DIR (node)->children; item;
 		     item = item->next) {
@@ -2293,18 +2416,18 @@ model_fill (GeditFileBrowserStore * model, FileBrowserNode * node,
 				model_fill (model, child, path);
 
 				/* Increase path for next child */
-				gtk_tree_path_next (path);
+				gtk_tree_path_next (*path);
 			}
 		}
 
 		/* Move back up to node path */
-		gtk_tree_path_up (path);
+		gtk_tree_path_up (*path);
 	}
 	
 	model_check_dummy (model, node);
 
 	if (free_path)
-		gtk_tree_path_free (path);
+		gtk_tree_path_free (*path);
 }
 
 static void
@@ -2317,6 +2440,7 @@ set_virtual_root_from_node (GeditFileBrowserStore * model,
 	FileBrowserNodeDir *dir;
 	GSList *item;
 	GSList *copy;
+	GtkTreePath *empty = NULL;
 
 	prev = node;
 	next = prev->parent;
@@ -2381,7 +2505,7 @@ set_virtual_root_from_node (GeditFileBrowserStore * model,
 
 	/* Now finally, set the virtual root, and load it up! */
 	model->priv->virtual_root = node;
-	model_fill (model, NULL, NULL);
+	model_fill (model, NULL, &empty);
 
 	if (!NODE_LOADED (node))
 		model_load_directory (model, node);
@@ -3193,8 +3317,8 @@ file_deleted (IdleDelete * data)
 {
 	FileBrowserNode * node;
 	node = model_find_node (data->model, NULL, data->file);
-	    	
-	if (node)
+
+	if (node != NULL)
 		model_remove_node (data->model, node, NULL, TRUE);
 	
 	return FALSE;
